##
##  l2.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         l2
Summary:      Flexible Logging Library
URL:          http://www.ossp.org/pkg/lib/l2/
Vendor:       The OSSP Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Libraries
License:      MIT-style
Version:      0.9.13
Release:      20181229

#   list of sources
Source0:      http://www.ossp.org/pkg/lib/l2/l2-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    OSSP l2 is a C library providing a very flexible and sophisticated
    Unix logging facility. It is based on the model of arbitrary number
    of channels, stacked together in a top-down data flow tree structure
    with filtering channels in internal nodes and output channels on the
    leave nodes.

    Channel trees can be either constructed manually through lower-level
    API functions or all at once with a single API function controlled by
    a compact syntactical description of the channel tree. For generating
    log messages a printf-style formatting engine is provided which can be
    extended through callback functions. The data flow inside the channel
    tree is controlled by (eight fixed and nine custom) logging message
    severity levels which are assigned to each individual channel.

    Channels are implemented by channel handlers which can be even
    customer supplied for creating own channels which seamlessly integrate
    into the framework. For convenience reasons, OSSP l2 already ships
    with pre-implemented filtering (noop, filter, prefix, buffer) and
    output (null, fd, file, pipe, socket, syslog, smtp) channels which
    already cover mostly all use cases of logging.

%track
    prog l2 = {
        version   = %{version}
        url       = http://www.ossp.org/pkg/lib/l2/
        regex     = l2-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %{l_shtool} subst \
        -e '/LINENO: error: C[+]* preprocessor/{N;N;N;N;s/.*/:/;}' \
        configure

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-shared
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

